function [L,S] = pcp(Y)
% Principal Component Pursuit solved with ADMM
% 
% Syntax:       [L,S] = pcp(Y)
%
% Inputs:       Y is a matrix of size (D x N)
%
% Outputs:      L is a low-rank matrix of size (D x N)
%               S is a sparse matrix of size (D x N)

% parameters we'll use
[D,N] = size(Y);
normY = norm(Y,'fro');

% algorithm parameters
lambda = 1/sqrt(max(D,N));
rho = 10*lambda;
tol = 1e-4;
maxIter = 1000;

% initialize optimization variables
L = zeros(D,N);
S = zeros(D,N);
Z = zeros(D,N);

for ii = 1:maxIter
    L = svt(Y-S+(1/rho)*Z,1/rho);
    S = st(Y-L+(1/rho)*Z,lambda/rho);
    E = Y - L - S;
    Z = Z + rho*E;

    % calculate error and output it at each iteration
    err = norm(E,'fro')/normY;
    err
    if err < tol
        break
    end
end
